Package 'peutils'

Title: Utilities Developed by the Predictive Ecology Group
Description: Dependency-free utilities developed by the Predictive Ecology Group (<http://predictiveecology.org>). (Do not depend on contributed R packages).
Authors: Eliot J B McIntire [aut, cre] (ORCID: <https://orcid.org/0000-0002-6914-8316>), Alex M Chubaty [aut] (ORCID: <https://orcid.org/0000-0001-7146-8135>), His Majesty the Queen in Right of Canada, as represented by the Minister of Natural Resources Canada [cph]
Maintainer: Eliot J B McIntire <[email protected]>
License: GPL-3
Version: 0.1.1
Built: 2026-05-26 06:57:16 UTC
Source: https://github.com/PredictiveEcology/peutils

Help Index


Convert a character string to sentence case

Description

Convert a character string to sentence case

Usage

toSentenceCase(x)

Arguments

x

A character string.


Determine name of current user

Description

Determine name of current user

Usage

user(username = NULL)

Arguments

username

Character.

Value

Logical indicating whether the current user matches username; or, if username is NULL, a character string indicating the current user.